package com.loafle.overflow.container.service;

import java.util.Map;

import javax.annotation.Resource;

import com.loafle.overflow.container.Container;
import com.loafle.overflow.crawler.Crawler;
import com.loafle.overflow.module.core.exception.OverflowException;
import com.loafle.overflow.module.core.interfaces.Service;
import com.loafle.overflow.module.sensorconfig.model.SensorConfig;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;

/**
 * CrawlerService
 */
@org.springframework.stereotype.Service("CrawlerService")
public class CrawlerService implements Service {
  private static final Logger logger = LoggerFactory.getLogger(CrawlerService.class);

  @Autowired
  private SensorConfigService sensorConfigService;

  @Resource(name=Container.CONTAINER_CRAWLERS)
  private Map<String, Crawler> crawlers;

	@Override
	public void initService() throws Exception {
		if (null == this.crawlers) {
      throw new Exception("Crawlers is not set");
    }
	}

	@Override
	public void startService() throws Exception {
		
	}

	@Override
	public void stopService() {
		
	}

  @Override
	public void destroyService() {
		
	}

  public void Auth(String crawlerName, Map<String, Object> authInfoMap) throws OverflowException {
    Crawler crawler = this.crawlers.get(crawlerName);
    if (null == crawler) {
      throw new OverflowException(String.format("There is no crawler[%s]", crawlerName), null);
    }

    crawler.auth(authInfoMap);
  }

  public Map<String, String> Get(String sensorConfigID) throws OverflowException {
    SensorConfig sensorConfig = this.sensorConfigService.getSensorConfig(sensorConfigID);
    if (null == sensorConfig) {
      throw new OverflowException(String.format("There is no sensor config for id[%s]", sensorConfigID), null);
    }

    String crawlerName = sensorConfig.getCrawler().getName();
    Crawler crawler = this.crawlers.get(crawlerName);
    if (null == crawler) {
      throw new OverflowException(String.format("There is no crawler[%s] for id[%s]", crawlerName, sensorConfigID), null);
    }

    return crawler.get(sensorConfig);
  }

}
